pub enum OColumnName {
String = 1,
Unsigned = 2,
Signed = 3,
Float = 4,
Double = 5,
Points = 6,
Points3D = 7,
Indices = 8,
Shapes = 9,
BBox = 10,
}Expand description
Column Types take up 3 bits. ColumnNames define various common data structures to be stored in a column fashion
Variants
String = 1
stores string values
Unsigned = 2
Note: IDs are stored in unsigned Number types are sorted prior to storing
Signed = 3
Number types are sorted prior to storing
Float = 4
Floating precision helps ensure only 32 bit cost Number types are sorted prior to storing
Double = 5
worst case, no compression Number types are sorted prior to storing
Points = 6
points is an array of { x: number, y: number } points also stores lines. if a line is stored, note that it has an acompanying offset and potentially mValues Polygons are stored as a collection of lines. The points feature type that has more than one will be stored here as well.
Points3D = 7
points3D is an array of { x: number, y: number, z: number } points3D also stores lines. if a line is stored, note that it has an acompanying offset and potentially mValues Polygons are stored as a collection of lines. The points 3D feature type that has more than one will be stored here as well.
Indices = 8
store M-Value, Shape, and Value encodings store geometry shapes. store geometry indices.
Shapes = 9
Shapes describe how to rebuild objects
BBox = 10
BBox - specially compressed to reduce byte cost. each value is only 3 bytes worst case BBox3D - specially compressed to reduce byte cost. each value is only 3 bytes worst case. The z values are stored as floats and cost 4 bytes.